@@ -1,4 +1,4 @@
-import logging, coloredlogs
+import coloredlogs, logging
 
 logger=logging.getLogger(__name__)
 coloredlogs.install(level='DEBUG',logger=logger)
